webencodings: Character encoding aliases for legacy web content
===============================================================

Description
-----------

Character encoding aliases for legacy web content.

License
-------

BSD License


Upstream Contact
----------------

Home Page: https://github.com/gsnedders/python-webencodings

Dependencies
------------

Python
